# This file was auto-generated by Fern from our API Definition.

import typing

StyleGuides = typing.Union[
    typing.Literal["ap", "chicago", "microsoft", "proofpoint", "style_brand_importer"], typing.Any
]
