# This file was auto-generated by Fern from our API Definition.

import typing

StyleGuideCategory = typing.Union[
    typing.Literal[
        "punctuation",
        "capitalization",
        "spelling_and_grammar",
        "numbers_dates_times",
        "inclusive_language",
        "tone",
        "specific_conventions",
        "clarity_and_readability",
        "other",
    ],
    typing.Any,
]
