# This file was auto-generated by Fern from our API Definition.

import typing

IssueCategory = typing.Union[
    typing.Literal[
        "grammar", "sentence_length", "sentence_structure", "simple_vocab", "style_guide", "terminology", "tone"
    ],
    typing.Any,
]
