# This file was auto-generated by Fern from our API Definition.

import typing

ContentSuggestions = typing.Union[
    typing.Literal[
        "Use shorter sentences and simpler words to improve readability.",
        "Your text may be too complex. Consider simplifying vocabulary and sentence structure.",
        "Your sentences are quite long. Consider breaking them into shorter ones.",
        "Your sentences are very short. Consider combining some for better flow.",
        "Your vocabulary diversity is low. Try using a wider range of words.",
        "Your text is well-balanced. Consider proofreading for minor improvements.",
    ],
    typing.Any,
]
