# This file was auto-generated by Fern from our API Definition.

import typing

ContentQualityFeedback = typing.Union[
    typing.Literal[
        "Excellent content quality! Your text is clear, readable, and well-structured.",
        "Good content quality. Your text is readable but has room for improvement.",
        "Moderate content quality. Consider revising for better readability.",
        "Low content quality. The text needs significant revision for better readability.",
    ],
    typing.Any,
]
