# This file was auto-generated by Fern from our API Definition.

import typing

Tones = typing.Union[
    typing.Literal["academic", "business", "casual", "conversational", "formal", "gen-z", "informal", "technical"],
    typing.Any,
]
