# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .acrolinx_scorer_activity_output import AcrolinxScorerActivityOutput
from .content_scorer_activity_output import ContentScorerActivityOutput
from .issue_scores import IssueScores


class InitialScores(UniversalBaseModel):
    acrolinx_score: typing.Optional[AcrolinxScorerActivityOutput] = None
    content_score: typing.Optional[ContentScorerActivityOutput] = None
    issue_score: typing.Optional[IssueScores] = None
    quality_score: typing.Optional[int] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
