# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .dialects import Dialects
from .style_guide import StyleGuide
from .tones import Tones


class CheckOptions(UniversalBaseModel):
    style_guide: typing.Optional[StyleGuide] = None
    dialect: typing.Optional[Dialects] = None
    tone: typing.Optional[Tones] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
