# This file was auto-generated by Fern from our API Definition.

import typing

from .grammar_category import GrammarCategory
from .sentence_length_category import SentenceLengthCategory
from .sentence_structure_category import SentenceStructureCategory
from .simple_vocab_category import SimpleVocabCategory
from .style_guide_category import StyleGuideCategory
from .term_replace_category import TermReplaceCategory
from .tone_category import ToneCategory

Subcategory = typing.Union[
    GrammarCategory,
    SimpleVocabCategory,
    SentenceStructureCategory,
    SentenceLengthCategory,
    ToneCategory,
    StyleGuideCategory,
    TermReplaceCategory,
]
