# This file was auto-generated by Fern from our API Definition.

import typing

Dialects = typing.Union[
    typing.Literal["american_english", "australian_english", "british_oxford", "canadian_english", "indian_english"],
    typing.Any,
]
