# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .clarity_score import ClarityScore
from .grammar_score import GrammarScore
from .quality_score import QualityScore
from .style_guide_score import StyleGuideScore
from .terminology_score import TerminologyScore
from .tone_score import ToneScore


class ScoreOutput(UniversalBaseModel):
    quality: QualityScore
    clarity: ClarityScore
    grammar: GrammarScore
    style_guide: StyleGuideScore
    tone: ToneScore
    terminology: TerminologyScore

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
