# This file was auto-generated by Fern from our API Definition.

import typing

SentenceStructureCategory = typing.Union[
    typing.Literal[
        "complex_verbs", "hidden_verbs", "insertion", "modal_verbs", "passive", "phrasal_verbs", "subjunctive", "other"
    ],
    typing.Any,
]
