# This file was auto-generated by Fern from our API Definition.

import typing

GrammarCategory = typing.Union[
    typing.Literal["sva_pronoun", "punct_cap", "spelling", "syntax", "verbs", "word_usage", "other"], typing.Any
]
