# This file was auto-generated by Fern from our API Definition.

import typing

ToneCategory = typing.Union[
    typing.Literal["word_choice", "syntax", "punctuation", "discourse_features", "implicit_style", "other"], typing.Any
]
