# This file was auto-generated by Fern from our API Definition.

import typing

SentenceLengthCategory = typing.Union[
    typing.Literal["capitalization", "remove", "extract", "shorten", "deletion", "replace", "other"], typing.Any
]
